
import React, { useState, useEffect, memo } from 'react';
import { ArrowRight, Share } from 'lucide-react';
import { useNavigate } from 'react-router-dom';
import { useTranslation } from 'react-i18next';
import ScrollAnimation from './ScrollAnimation';
import { useIsMobile } from '@/hooks/use-mobile';

// Memoize the Hero component to prevent unnecessary re-renders
const Hero = memo(() => {
  const navigate = useNavigate();
  const { t, i18n } = useTranslation();
  const [showFloatingButton, setShowFloatingButton] = useState(false);
  const isRTL = i18n.language === 'ar';
  const isMobile = useIsMobile();
  const [isCopied, setIsCopied] = useState(false);

  useEffect(() => {
    // Add loading attribute to LCP element to prioritize rendering
    const lcpElement = document.querySelector('.hero-title');
    if (lcpElement instanceof HTMLElement) {
      lcpElement.setAttribute('fetchpriority', 'high');
    }

    const handleScroll = () => {
      const heroSection = document.getElementById('hero-section');
      const originalButton = document.getElementById('original-pitch-button');
      
      if (heroSection && originalButton) {
        const rect = originalButton.getBoundingClientRect();
        setShowFloatingButton(rect.bottom < 0);
      }
    };

    // Check if the URL has a hero-section hash and scroll to it
    if (window.location.hash === '#hero-section') {
      const heroSection = document.getElementById('hero-section');
      if (heroSection) {
        heroSection.scrollIntoView({ behavior: 'smooth' });
      }
    }

    // Use passive event listener for better performance
    window.addEventListener('scroll', handleScroll, { passive: true });
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  const handleShare = () => {
    const shareUrl = `${window.location.origin}/#hero-section`;
    
    if (navigator.share) {
      navigator.share({
        title: 'Qora71 - Venture Investors Syndicate',
        url: shareUrl,
      }).catch(err => console.error('Error sharing:', err));
    } else {
      // Fallback to clipboard copy
      navigator.clipboard.writeText(shareUrl)
        .then(() => {
          setIsCopied(true);
          setTimeout(() => setIsCopied(false), 2000);
        })
        .catch(err => {
          console.error('Could not copy link:', err);
        });
    }
  };

  return (
    <section 
      id="hero-section" 
      className="bg-black text-white min-h-[70vh] flex items-center relative overflow-hidden py-10 md:py-16 mt-10"
      style={{
        backgroundImage: 'linear-gradient(to right, rgba(0,0,0,0.95), rgba(0,0,0,0.8))',
        backgroundSize: 'cover',
        backgroundPosition: 'center'
      }}
    >
      {/* Background overlay with gradient */}
      <div className="absolute inset-0 bg-gradient-to-r from-black/80 to-black/60 z-0"></div>
      
      <div className="container-section max-w-screen-xl mx-auto relative z-10">
        <div className="max-w-3xl">
          <div className="flex justify-between items-start mb-2">
            <ScrollAnimation 
              direction="up" 
              duration={0.7} 
              className={isRTL ? "text-right" : "text-left"}
              disabled={isMobile} // Disable animations on mobile to prevent jump
            >
              <h1 className="hero-title text-4xl md:text-6xl font-light mb-4 leading-tight">
                <span className="text-white">
                  {t('hero.title')}
                </span>
              </h1>
            </ScrollAnimation>
            
            <button 
              onClick={handleShare}
              className="flex items-center justify-center p-2 bg-qora-red/10 hover:bg-qora-red/20 text-white rounded-full transition-colors"
              aria-label="Share"
            >
              <Share className="h-5 w-5" />
              {isCopied && (
                <span className="absolute -bottom-8 whitespace-nowrap bg-black/80 text-white text-xs px-2 py-1 rounded">
                  Link copied!
                </span>
              )}
            </button>
          </div>
          
          <ScrollAnimation 
            direction="up" 
            delay={0.2} 
            duration={0.7}
            className={isRTL ? "text-right" : "text-left"}
            disabled={isMobile} // Disable animations on mobile to prevent jump
          >
            <p className="text-lg md:text-xl mb-6 text-gray-400 font-light">
              {t('hero.subtitle')}
            </p>
          </ScrollAnimation>
          
          <ScrollAnimation 
            direction="up" 
            delay={0.3} 
            duration={0.7}
            disabled={isMobile} // Disable animations on mobile to prevent jump
          >
            <div className={`flex flex-col-reverse sm:flex-row gap-4 ${isRTL ? "sm:justify-end" : ""}`}>
              <button 
                onClick={() => navigate('/learn-more')}
                className="border border-white px-6 py-3 inline-flex items-center hover:bg-white hover:text-black transition-colors"
              >
                {t('hero.learnMore')}
              </button>
              <button 
                id="original-pitch-button"
                onClick={() => navigate('/survey')}
                className="bg-[#ea384c] text-white px-6 py-3 inline-flex items-center gap-2 group hover:bg-[#d32d3f] transition-colors"
              >
                {!isRTL && t('hero.pitchUs')}
                <ArrowRight className={`w-5 h-5 transition-transform duration-300 ${isRTL ? "rotate-180 group-hover:-translate-x-1" : "group-hover:translate-x-1"}`} />
                {isRTL && t('hero.pitchUs')}
              </button>
            </div>
          </ScrollAnimation>
        </div>
      </div>

      {showFloatingButton && (
        <button 
          onClick={() => navigate('/survey')}
          className={`fixed bottom-8 ${isRTL ? "left-8" : "right-8"} z-50 bg-[#ea384c] text-white px-8 py-4 inline-flex items-center gap-2 group hover:bg-[#d32d3f] transition-colors shadow-lg hover:shadow-xl`}
        >
          {!isRTL && t('hero.pitchUs')}
          <ArrowRight className={`w-5 h-5 transition-transform duration-300 ${isRTL ? "rotate-180 group-hover:-translate-x-1" : "group-hover:translate-x-1"}`} />
          {isRTL && t('hero.pitchUs')}
        </button>
      )}
    </section>
  );
});

export default Hero;
